Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(936)

Unified Diff: content/public/browser/browser_context.h

Issue 9568002: Renamed speech input implementation from to speech_recognition_*. The namespace has been renamed fr… (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Rebased from master. Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/content_renderer.gypi ('k') | content/public/browser/content_browser_client.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/browser_context.h
diff --git a/content/public/browser/browser_context.h b/content/public/browser/browser_context.h
index 60786dcf8b9091a2738ac6ca9c6fbd96a474c5bb..7a4577e4bc7e5df7de6261bcf5f4513205269964 100644
--- a/content/public/browser/browser_context.h
+++ b/content/public/browser/browser_context.h
@@ -40,7 +40,7 @@ class DownloadManager;
class GeolocationPermissionContext;
class IndexedDBContext;
class ResourceContext;
-class SpeechInputPreferences;
+class SpeechRecognitionPreferences;
// This class holds the context needed for a browsing session.
// It lives on the UI thread.
@@ -110,9 +110,9 @@ class CONTENT_EXPORT BrowserContext : public base::SupportsUserData {
// Returns the geolocation permission context for this context.
virtual GeolocationPermissionContext* GetGeolocationPermissionContext() = 0;
// Returns the speech input preferences. SpeechInputPreferences is a
// ref counted class, so callers should take a reference if needed.
- virtual SpeechInputPreferences* GetSpeechInputPreferences() = 0;
+ virtual SpeechRecognitionPreferences* GetSpeechRecognitionPreferences() = 0;
// Returns true if the last time this context was open it was exited cleanly.
// This doesn't belong here; http://crbug.com/90737
« no previous file with comments | « content/content_renderer.gypi ('k') | content/public/browser/content_browser_client.h » ('j') | no next file with comments »
@@ -110,9 +110,9 @@ class CONTENT_EXPORT BrowserContext : public base::SupportsUserData {
// Returns the geolocation permission context for this context.
virtual GeolocationPermissionContext* GetGeolocationPermissionContext() = 0;
- // Returns the speech input preferences. SpeechInputPreferences is a
+ // Returns the speech input preferences. SpeechRecognitionPreferences is a
// ref counted class, so callers should take a reference if needed.

Powered by Google App Engine
This is Rietveld 408576698